==> piwigo-11.5.0.zip: piwigo/plugins/LocalFilesEditor/language/ja_JP/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2014 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'ローカルconfig';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'テンプレート';
$lang['locfiledit_onglet_lang'] = '言語';
$lang['locfiledit_onglet_plug'] = '個人のプラグイン';
$lang['locfiledit_cant_save'] = '現在のファイルは書き込みできません。"local/"というディレクトリーは書き込める(chmod)か確認して下さい。';
$lang['locfiledit_newfile'] = 'ファイルがありませんので、ローカルファイルエディターで作成されます。';
$lang['locfiledit_save_config'] = 'ファイル書き込み成功';
$lang['locfiledit_show_default'] = '参照ファイル展示: ';
$lang['locfiledit_save_bak'] = '保存する時に、バックアップコピーが作成される。';
$lang['locfiledit_saved_bak'] = 'バックアップファイル作成されました(%s)';
$lang['locfiledit_save_file'] = 'ファイル保存';
$lang['locfiledit_choose_file'] = '編集ファイルを選択して下さい。';
$lang['locfiledit_edit'] = '編集';
$lang['locfiledit_restore'] = 'バックアップファイルを復元する';
$lang['locfiledit_restore_confirm'] = '確認して下さい?
次の保存するまでに現在の復元は有効になりません。';
$lang['locfiledit_bak_loaded1'] = 'バックアップファイルは起動しました。';
$lang['locfiledit_bak_loaded2'] = '復元するために、ファイルを保存する必要があります。';
$lang['locfiledit_syntax_error'] = 'エラー! ファイルは保存できません。';
$lang['locfiledit_new_tpl'] = '新しいファイルを作成する';
$lang['locfiledit_new_filename'] = 'ファイル名';
$lang['locfiledit_model'] = 'モデル';
$lang['locfiledit_empty_page'] = '空のページ';
$lang['locfiledit_parent_directory'] = '親ディレクトリー';
$lang['locfiledit_filename_error'] = '入ってはいけない文字はファイル名にあります。';
$lang['locfiledit_file_already_exists'] = 'ファイルは既に存在しています。';
$lang['locfiledit_model_error'] = 'モデルを選択する必要があります。';
$lang['locfiledit_empty_filename'] = 'ファイル名を記入する必要があります。';
$lang['locfiledit_webmaster_only'] = 'ローカルファイルはウェブマスターのみ作成するか、変更できます。';
$lang['Customize CSS'] = 'CSSをカスタマイズする';

==> piwigo-15.7.0.zip: piwigo/plugins/LocalFilesEditor/language/ja_JP/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2014 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'ローカル設定';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'テンプレート';
$lang['locfiledit_onglet_lang'] = '言語';
$lang['locfiledit_onglet_plug'] = '個人のプラグイン';
$lang['locfiledit_cant_save'] = '現在のファイルは書き込みできません。"local/"というディレクトリーは書き込めるか確認して下さい(chmod)。';
$lang['locfiledit_newfile'] = '以下に情報を入力するまでファイルは作成されません。情報を入力し保存することで、ファイルが作成されます。';
$lang['locfiledit_save_config'] = 'ファイルの書き込みが成功しました。';
$lang['locfiledit_show_default'] = '表示参照ファイル: ';
$lang['locfiledit_save_bak'] = '保存すると、バックアップコピーが作成されます。';
$lang['locfiledit_saved_bak'] = 'バックアップファイルが作成されました(%s)';
$lang['locfiledit_save_file'] = 'ファイルを保存する';
$lang['locfiledit_choose_file'] = '編集するファイルを選択して下さい。';
$lang['locfiledit_edit'] = '編集';
$lang['locfiledit_restore'] = 'バックアップファイルを復元する';
$lang['locfiledit_restore_confirm'] = '確認して下さい?
次の保存するまでに現在の復元は有効になりません。';
$lang['locfiledit_bak_loaded1'] = 'バックアップファイルを読み込みました。';
$lang['locfiledit_bak_loaded2'] = '復元するために、ファイルを保存する必要があります。';
$lang['locfiledit_syntax_error'] = '構文エラーです! ファイルは保存できません。';
$lang['locfiledit_new_tpl'] = '新しいファイルを作成する';
$lang['locfiledit_new_filename'] = 'ファイル名';
$lang['locfiledit_model'] = 'モデル';
$lang['locfiledit_empty_page'] = '空のページ';
$lang['locfiledit_parent_directory'] = '親ディレクトリー';
$lang['locfiledit_filename_error'] = '利用できない文字がファイル名に利用されています。';
$lang['locfiledit_file_already_exists'] = 'ファイルは既に存在しています。';
$lang['locfiledit_model_error'] = 'モデルを選択する必要があります。';
$lang['locfiledit_empty_filename'] = 'ファイル名を入力する必要があります。';
$lang['locfiledit_webmaster_only'] = 'ウェブマスターのみが、ローカルファイルを作成・変更できます。';
$lang['Customize CSS'] = 'CSSをカスタマイズする';
